@@ -853,7 +853,7 @@ impl Client {
     }
 
     /// Get or refresh token
-    pub(crate) async fn authorize(&mut self) -> Result<bool> {
+    pub async fn authorize(&mut self) -> Result<bool> {
         use chrono::{Duration, Utc};
         if Utc::now() - Duration::seconds(1) < self.bearer_expires_at {
             return Ok(true);
